From 4e3379badb28e1f3650830a0de79c38201630ff5 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Benedek=20L=C3=A1szl=C3=B3?= <laszlo.benedek@hu.digi.tv>
Date: Thu, 22 Jul 2010 17:12:27 +0200
Subject: [PATCH] Role support in global and server backups

Add the possibility to specify a rolename for pg_dump
---
 pgadmin/frm/frmBackupGlobals.cpp |   19 ++
 pgadmin/frm/frmBackupServer.cpp  |   11 +
 pgadmin/ui/frmBackupGlobals.xrc  |   12 +-
 pgadmin/ui/frmBackupServer.xrc   |   12 +-
 pgadmin/ui/xrcDialogs.cpp        |  457 ++++++++++++++++++++------------------
 5 files changed, 293 insertions(+), 218 deletions(-)

diff --git a/pgadmin/frm/frmBackupGlobals.cpp b/pgadmin/frm/frmBackupGlobals.cpp
index c876c1c..d16d09a 100644
--- a/pgadmin/frm/frmBackupGlobals.cpp
+++ b/pgadmin/frm/frmBackupGlobals.cpp
@@ -29,12 +29,14 @@
 #define nbNotebook              CTRL_NOTEBOOK("nbNotebook")
 #define txtFilename             CTRL_TEXT("txtFilename")
 #define btnFilename             CTRL_BUTTON("btnFilename")
+#define txtRolename             CTRL_TEXT("txtRolename")
 #define chkVerbose              CTRL_CHECKBOX("chkVerbose")
 
 
 BEGIN_EVENT_TABLE(frmBackupGlobals, ExternProcessDialog)
     EVT_TEXT(XRCID("txtFilename"),          frmBackupGlobals::OnChange)
     EVT_BUTTON(XRCID("btnFilename"),        frmBackupGlobals::OnSelectFilename)
+    EVT_TEXT(XRCID("txtRolename"),          frmBackupGlobals::OnChange)
     EVT_BUTTON(wxID_OK,                     frmBackupGlobals::OnOK)
     EVT_CLOSE(                              ExternProcessDialog::OnClose)
 END_EVENT_TABLE()
@@ -62,6 +64,12 @@ frmBackupGlobals::frmBackupGlobals(frmMain *form, pgObject *obj) : ExternProcess
 
 		// Pass the SSL mode via the environment
 		environment.Add(wxT("PGSSLMODE=") + ((pgServer *)object)->GetConnection()->GetSslModeName());
+
+		if (pgAppMinimumVersion(pgBackupExecutable + wxT(" --version"), 8, 4)) {
+		    txtRolename->SetValue(object->GetServer()->GetRolename());
+		} else {
+		    txtRolename->Enable(false);
+		}
 	}
 	else
 	{
@@ -70,6 +78,12 @@ frmBackupGlobals::frmBackupGlobals(frmMain *form, pgObject *obj) : ExternProcess
 
 		// Pass the SSL mode via the environment
 		environment.Add(wxT("PGSSLMODE=") + object->GetServer()->GetConnection()->GetSslModeName());
+
+		if (pgAppMinimumVersion(pgBackupExecutable + wxT(" --version"), 8, 4)) {
+		    txtRolename->SetValue(((pgServer *)object)->GetRolename());
+		} else {
+		    txtRolename->Enable(false);
+		}
 	}
 
     // Icon
@@ -163,6 +177,11 @@ wxString frmBackupGlobals::getCmdPart1()
 
     cmd +=  wxT(" --port ") + NumToStr((long)server->GetPort())
          +  wxT(" --username ") + commandLineCleanOption(qtIdent(server->GetUsername()));
+
+    if (!txtRolename->GetValue().IsEmpty()) {
+        cmd +=  wxT(" --role ") + commandLineCleanOption(qtIdent(txtRolename->GetValue()));
+    }
+
     return cmd;
 }
 
diff --git a/pgadmin/frm/frmBackupServer.cpp b/pgadmin/frm/frmBackupServer.cpp
index a6d5a84..f3a6f4a 100644
--- a/pgadmin/frm/frmBackupServer.cpp
+++ b/pgadmin/frm/frmBackupServer.cpp
@@ -29,6 +29,7 @@
 #define nbNotebook              CTRL_NOTEBOOK("nbNotebook")
 #define txtFilename             CTRL_TEXT("txtFilename")
 #define btnFilename             CTRL_BUTTON("btnFilename")
+#define txtRolename             CTRL_TEXT("txtRolename")
 #define chkVerbose              CTRL_CHECKBOX("chkVerbose")
 
 
@@ -61,6 +62,12 @@ frmBackupServer::frmBackupServer(frmMain *form, pgObject *obj) : ExternProcessDi
 	// Pass the SSL mode via the environment
 	environment.Add(wxT("PGSSLMODE=") + ((pgServer *)object)->GetConnection()->GetSslModeName());
 
+	if (pgAppMinimumVersion(pgBackupExecutable + wxT(" --version"), 8, 4)) {
+	    txtRolename->SetValue(((pgServer *)object)->GetRolename());
+	} else {
+	    txtRolename->Enable(false);
+	}
+
 	// Icon
     SetIcon(wxIcon(backup_xpm));
 
@@ -148,6 +155,10 @@ wxString frmBackupServer::getCmdPart1()
 
     cmd +=  wxT(" --port ") + NumToStr((long)server->GetPort())
          +  wxT(" --username ") + commandLineCleanOption(qtIdent(server->GetUsername()));
+    if (!txtRolename->GetValue().IsEmpty()) {
+        cmd +=  wxT(" --role ") + commandLineCleanOption(qtIdent(txtRolename->GetValue()));
+    }
+
     return cmd;
 }
 
diff --git a/pgadmin/ui/frmBackupGlobals.xrc b/pgadmin/ui/frmBackupGlobals.xrc
index f2561ee..37ca596 100644
--- a/pgadmin/ui/frmBackupGlobals.xrc
+++ b/pgadmin/ui/frmBackupGlobals.xrc
@@ -6,7 +6,7 @@
     <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
-      <rows>2</rows>
+      <rows>3</rows>
       <object class="sizeritem">
         <object class="wxNotebook" name="nbNotebook">
           <object class="notebookpage">
@@ -25,10 +25,18 @@
                 <pos>220,5d</pos>
                 <size>15,-1d</size>
               </object>
+              <object class="wxStaticText" name="stRolename">
+                <label>Rolename</label>
+                <pos>8,27d</pos>
+              </object>
+              <object class="wxTextCtrl" name="txtRolename">
+                <pos>65,25d</pos>
+                <size>150,-1d</size>
+              </object>
               <style></style>
               <object class="wxStaticText" name="txtNote">
                 <label>Note: Only objects global to the entire database cluster will be backed\nup. The backup format will be PLAIN.</label>
-                <pos>8,25d</pos>
+                <pos>8,47d</pos>
                 <style></style>
               </object>
               <object class="wxCheckBox" name="chkVerbose">
diff --git a/pgadmin/ui/frmBackupServer.xrc b/pgadmin/ui/frmBackupServer.xrc
index 997098a..066ac75 100644
--- a/pgadmin/ui/frmBackupServer.xrc
+++ b/pgadmin/ui/frmBackupServer.xrc
@@ -6,7 +6,7 @@
     <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
-      <rows>2</rows>
+      <rows>3</rows>
       <object class="sizeritem">
         <object class="wxNotebook" name="nbNotebook">
           <object class="notebookpage">
@@ -25,10 +25,18 @@
                 <pos>220,5d</pos>
                 <size>15,-1d</size>
               </object>
+              <object class="wxStaticText" name="stRolename">
+                <label>Rolename</label>
+                <pos>8,27d</pos>
+              </object>
+              <object class="wxTextCtrl" name="txtRolename">
+                <pos>65,25d</pos>
+                <size>150,-1d</size>
+              </object>
               <style></style>
               <object class="wxStaticText" name="txtNote">
                 <label>Note: The backup format will be PLAIN.</label>
-                <pos>8,25d</pos>
+                <pos>8,47d</pos>
                 <style></style>
               </object>
               <object class="wxCheckBox" name="chkVerbose">
diff --git a/pgadmin/ui/xrcDialogs.cpp b/pgadmin/ui/xrcDialogs.cpp
index 17211ce..1939bdc 100644
--- a/pgadmin/ui/xrcDialogs.cpp
+++ b/pgadmin/ui/xrcDialogs.cpp
@@ -25456,7 +25456,7 @@ static unsigned char xml_res_file_58[] = {
 62,10,32,32,60,47,111,98,106,101,99,116,62,10,60,47,114,101,115,111,117,
 114,99,101,62,10};
 
-static size_t xml_res_size_59 = 3487;
+static size_t xml_res_size_59 = 3802;
 static unsigned char xml_res_file_59[] = {
 60,63,120,109,108,32,118,101,114,115,105,111,110,61,34,49,46,48,34,32,101,
 110,99,111,100,105,110,103,61,34,73,83,79,45,56,56,53,57,45,49,34,63,62,
@@ -25474,7 +25474,7 @@ static unsigned char xml_res_file_59[] = {
 32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,70,108,101,
 120,71,114,105,100,83,105,122,101,114,34,62,10,32,32,32,32,32,32,60,99,
 111,108,115,62,49,60,47,99,111,108,115,62,10,32,32,32,32,32,32,60,114,111,
-119,115,62,50,60,47,114,111,119,115,62,10,32,32,32,32,32,32,60,111,98,106,
+119,115,62,51,60,47,114,111,119,115,62,10,32,32,32,32,32,32,60,111,98,106,
 101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,
 34,62,10,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,
 115,115,61,34,119,120,78,111,116,101,98,111,111,107,34,32,110,97,109,101,
@@ -25508,119 +25508,134 @@ static unsigned char xml_res_file_59[] = {
 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,105,122,101,62,49,53,
 44,45,49,100,60,47,115,105,122,101,62,10,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,60,115,116,121,108,101,47,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,
-120,83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,101,61,34,116,
-120,116,78,111,116,101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,60,108,97,98,101,108,62,78,111,116,101,58,32,79,110,108,121,32,
-111,98,106,101,99,116,115,32,103,108,111,98,97,108,32,116,111,32,116,104,
-101,32,101,110,116,105,114,101,32,100,97,116,97,98,97,115,101,32,99,108,
-117,115,116,101,114,32,119,105,108,108,32,98,101,32,98,97,99,107,101,100,
-92,110,117,112,46,32,84,104,101,32,98,97,99,107,117,112,32,102,111,114,
-109,97,116,32,119,105,108,108,32,98,101,32,80,76,65,73,78,46,60,47,108,
-97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-112,111,115,62,56,44,50,53,100,60,47,112,111,115,62,10,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,60,115,116,121,108,101,47,62,10,32,32,32,
+32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,
+120,83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,101,61,34,115,
+116,82,111,108,101,110,97,109,101,34,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,108,97,98,101,108,62,82,111,108,101,110,97,109,101,
+60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,112,111,115,62,56,44,50,55,100,60,47,112,111,115,62,10,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
-97,115,115,61,34,119,120,67,104,101,99,107,66,111,120,34,32,110,97,109,
-101,61,34,99,104,107,86,101,114,98,111,115,101,34,62,10,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,86,101,114,98,
-111,115,101,32,109,101,115,115,97,103,101,115,60,47,108,97,98,101,108,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,99,104,101,99,107,
-101,100,62,49,60,47,99,104,101,99,107,101,100,62,10,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,60,112,111,115,62,49,48,44,49,52,52,100,60,47,
-112,111,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,
-106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
-101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,115,101,108,101,
-99,116,101,100,62,49,60,47,115,101,108,101,99,116,101,100,62,10,32,32,32,
-32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,
-32,32,32,32,60,112,111,115,62,50,44,50,100,60,47,112,111,115,62,10,32,32,
-32,32,32,32,32,32,32,32,60,115,105,122,101,62,50,52,53,44,49,55,52,100,
-60,47,115,105,122,101,62,10,32,32,32,32,32,32,32,32,32,32,60,115,116,121,
-108,101,62,119,120,78,66,95,66,79,84,84,79,77,60,47,115,116,121,108,101,
-62,10,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
-97,115,115,61,34,110,111,116,101,98,111,111,107,112,97,103,101,34,62,10,
-32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,77,101,115,
-115,97,103,101,115,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
-84,101,120,116,67,116,114,108,34,32,110,97,109,101,61,34,116,120,116,77,
-101,115,115,97,103,101,115,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,115,116,121,108,101,62,119,120,84,69,95,77,85,76,84,73,76,73,78,
-69,124,119,120,84,69,95,82,69,65,68,79,78,76,89,124,119,120,72,83,67,82,
-79,76,76,60,47,115,116,121,108,101,62,10,32,32,32,32,32,32,32,32,32,32,
-32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,
-47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,47,111,98,106,
-101,99,116,62,10,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,84,
-79,80,124,119,120,66,79,84,84,79,77,124,119,120,76,69,70,84,124,119,120,
-82,73,71,72,84,124,119,120,69,88,80,65,78,68,124,119,120,71,82,79,87,124,
-119,120,65,76,73,71,78,95,67,69,78,84,82,69,60,47,102,108,97,103,62,10,
-32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,60,
-111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,
-116,101,109,34,62,10,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
-99,108,97,115,115,61,34,119,120,70,108,101,120,71,114,105,100,83,105,122,
-101,114,34,62,10,32,32,32,32,32,32,32,32,32,32,60,99,111,108,115,62,52,
-60,47,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,60,114,111,119,
-115,62,49,60,47,114,111,119,115,62,10,32,32,32,32,32,32,32,32,32,32,60,
-111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,
-116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
-101,99,116,32,99,108,97,115,115,61,34,119,120,66,117,116,116,111,110,34,
-32,110,97,109,101,61,34,119,120,73,68,95,72,69,76,80,34,62,10,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,38,97,109,112,
-59,72,101,108,112,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,112,111,115,62,50,44,49,51,53,100,60,47,112,111,115,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,84,
-79,80,124,119,120,66,79,84,84,79,77,124,119,120,76,69,70,84,124,119,120,
-82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,
-32,32,60,98,111,114,100,101,114,62,53,60,47,98,111,114,100,101,114,62,10,
-32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,
-32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,
-115,112,97,99,101,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,115,
-105,122,101,62,48,44,48,60,47,115,105,122,101,62,10,32,32,32,32,32,32,32,
+97,115,115,61,34,119,120,84,101,120,116,67,116,114,108,34,32,110,97,109,
+101,61,34,116,120,116,82,111,108,101,110,97,109,101,34,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,112,111,115,62,54,53,44,50,53,100,
+60,47,112,111,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,115,105,122,101,62,49,53,48,44,45,49,100,60,47,115,105,122,101,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,116,121,108,101,47,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,
+32,99,108,97,115,115,61,34,119,120,83,116,97,116,105,99,84,101,120,116,
+34,32,110,97,109,101,61,34,116,120,116,78,111,116,101,34,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,78,111,116,
+101,58,32,79,110,108,121,32,111,98,106,101,99,116,115,32,103,108,111,98,
+97,108,32,116,111,32,116,104,101,32,101,110,116,105,114,101,32,100,97,116,
+97,98,97,115,101,32,99,108,117,115,116,101,114,32,119,105,108,108,32,98,
+101,32,98,97,99,107,101,100,92,110,117,112,46,32,84,104,101,32,98,97,99,
+107,117,112,32,102,111,114,109,97,116,32,119,105,108,108,32,98,101,32,80,
+76,65,73,78,46,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,112,111,115,62,56,44,52,55,100,60,47,112,111,115,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,116,121,108,
+101,47,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
+101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
+101,99,116,32,99,108,97,115,115,61,34,119,120,67,104,101,99,107,66,111,
+120,34,32,110,97,109,101,61,34,99,104,107,86,101,114,98,111,115,101,34,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,
+108,62,86,101,114,98,111,115,101,32,109,101,115,115,97,103,101,115,60,47,
+108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,99,104,101,99,107,101,100,62,49,60,47,99,104,101,99,107,101,100,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,112,111,115,62,49,48,
+44,49,52,52,100,60,47,112,111,115,62,10,32,32,32,32,32,32,32,32,32,32,32,
 32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,
-60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,
-105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
-106,101,99,116,32,99,108,97,115,115,61,34,119,120,66,117,116,116,111,110,
-34,32,110,97,109,101,61,34,119,120,73,68,95,79,75,34,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,38,97,109,112,59,
-79,75,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,100,101,102,97,117,108,116,62,49,60,47,100,101,102,97,117,108,
-116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,112,111,115,62,57,
-51,44,49,51,53,100,60,47,112,111,115,62,10,32,32,32,32,32,32,32,32,32,32,
 32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,
-32,60,102,108,97,103,62,119,120,84,79,80,124,119,120,66,79,84,84,79,77,
-124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,
-53,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,60,
-47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,111,98,
-106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,
-109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,
-32,99,108,97,115,115,61,34,119,120,66,117,116,116,111,110,34,32,110,97,
-109,101,61,34,119,120,73,68,95,67,65,78,67,69,76,34,62,10,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,38,97,109,112,59,67,
-97,110,99,101,108,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,112,111,115,62,49,52,54,44,49,51,53,100,60,47,112,
-111,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,
-99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,
-120,84,79,80,124,119,120,66,79,84,84,79,77,124,119,120,76,69,70,84,124,
-119,120,82,73,71,72,84,124,119,120,69,88,80,65,78,68,124,119,120,71,82,
-79,87,124,119,120,65,76,73,71,78,95,82,73,71,72,84,60,47,102,108,97,103,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,
-53,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,60,
-47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,103,114,
-111,119,97,98,108,101,99,111,108,115,62,49,60,47,103,114,111,119,97,98,
-108,101,99,111,108,115,62,10,32,32,32,32,32,32,32,32,60,47,111,98,106,101,
-99,116,62,10,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,
-80,65,78,68,124,119,120,71,82,79,87,60,47,102,108,97,103,62,10,32,32,32,
-32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,60,103,114,
-111,119,97,98,108,101,99,111,108,115,62,48,60,47,103,114,111,119,97,98,
-108,101,99,111,108,115,62,10,32,32,32,32,32,32,60,103,114,111,119,97,98,
-108,101,114,111,119,115,62,48,60,47,103,114,111,119,97,98,108,101,114,111,
-119,115,62,10,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,60,47,
-111,98,106,101,99,116,62,10,60,47,114,101,115,111,117,114,99,101,62,10};
+32,60,115,101,108,101,99,116,101,100,62,49,60,47,115,101,108,101,99,116,
+101,100,62,10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,
+62,10,32,32,32,32,32,32,32,32,32,32,60,112,111,115,62,50,44,50,100,60,47,
+112,111,115,62,10,32,32,32,32,32,32,32,32,32,32,60,115,105,122,101,62,50,
+52,53,44,49,55,52,100,60,47,115,105,122,101,62,10,32,32,32,32,32,32,32,
+32,32,32,60,115,116,121,108,101,62,119,120,78,66,95,66,79,84,84,79,77,60,
+47,115,116,121,108,101,62,10,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
+101,99,116,32,99,108,97,115,115,61,34,110,111,116,101,98,111,111,107,112,
+97,103,101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,
+108,62,77,101,115,115,97,103,101,115,60,47,108,97,98,101,108,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,
+115,61,34,119,120,84,101,120,116,67,116,114,108,34,32,110,97,109,101,61,
+34,116,120,116,77,101,115,115,97,103,101,115,34,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,115,116,121,108,101,62,119,120,84,69,95,77,85,
+76,84,73,76,73,78,69,124,119,120,84,69,95,82,69,65,68,79,78,76,89,124,119,
+120,72,83,67,82,79,76,76,60,47,115,116,121,108,101,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,
+32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,
+47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,102,108,97,103,
+62,119,120,84,79,80,124,119,120,66,79,84,84,79,77,124,119,120,76,69,70,
+84,124,119,120,82,73,71,72,84,124,119,120,69,88,80,65,78,68,124,119,120,
+71,82,79,87,124,119,120,65,76,73,71,78,95,67,69,78,84,82,69,60,47,102,108,
+97,103,62,10,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,
+32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,
+122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,60,111,98,
+106,101,99,116,32,99,108,97,115,115,61,34,119,120,70,108,101,120,71,114,
+105,100,83,105,122,101,114,34,62,10,32,32,32,32,32,32,32,32,32,32,60,99,
+111,108,115,62,52,60,47,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,
+32,60,114,111,119,115,62,49,60,47,114,111,119,115,62,10,32,32,32,32,32,
+32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,
+105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,66,117,
+116,116,111,110,34,32,110,97,109,101,61,34,119,120,73,68,95,72,69,76,80,
+34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,
+62,38,97,109,112,59,72,101,108,112,60,47,108,97,98,101,108,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,112,111,115,62,50,44,49,51,53,100,
+60,47,112,111,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,
+106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,
+103,62,119,120,84,79,80,124,119,120,66,79,84,84,79,77,124,119,120,76,69,
+70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,53,60,47,98,111,114,
+100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,
+116,62,10,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,
+108,97,115,115,61,34,115,112,97,99,101,114,34,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,60,115,105,122,101,62,48,44,48,60,47,115,105,122,101,62,
+10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,
+32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
+34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
+66,117,116,116,111,110,34,32,110,97,109,101,61,34,119,120,73,68,95,79,75,
+34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,
+62,38,97,109,112,59,79,75,60,47,108,97,98,101,108,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,100,101,102,97,117,108,116,62,49,60,47,100,
+101,102,97,117,108,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,112,111,115,62,57,51,44,49,51,53,100,60,47,112,111,115,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,84,79,80,124,119,120,
+66,79,84,84,79,77,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,
+47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,
+100,101,114,62,53,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,
+32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,
+32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,
+114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,111,
+98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,66,117,116,116,111,
+110,34,32,110,97,109,101,61,34,119,120,73,68,95,67,65,78,67,69,76,34,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,38,
+97,109,112,59,67,97,110,99,101,108,60,47,108,97,98,101,108,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,112,111,115,62,49,52,54,44,49,51,
+53,100,60,47,112,111,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,47,
+111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,102,
+108,97,103,62,119,120,84,79,80,124,119,120,66,79,84,84,79,77,124,119,120,
+76,69,70,84,124,119,120,82,73,71,72,84,124,119,120,69,88,80,65,78,68,124,
+119,120,71,82,79,87,124,119,120,65,76,73,71,78,95,82,73,71,72,84,60,47,
+102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,
+100,101,114,62,53,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,
+32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,
+32,60,103,114,111,119,97,98,108,101,99,111,108,115,62,49,60,47,103,114,
+111,119,97,98,108,101,99,111,108,115,62,10,32,32,32,32,32,32,32,32,60,47,
+111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,102,108,97,103,62,
+119,120,69,88,80,65,78,68,124,119,120,71,82,79,87,60,47,102,108,97,103,
+62,10,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,
+32,60,103,114,111,119,97,98,108,101,99,111,108,115,62,48,60,47,103,114,
+111,119,97,98,108,101,99,111,108,115,62,10,32,32,32,32,32,32,60,103,114,
+111,119,97,98,108,101,114,111,119,115,62,48,60,47,103,114,111,119,97,98,
+108,101,114,111,119,115,62,10,32,32,32,32,60,47,111,98,106,101,99,116,62,
+10,32,32,60,47,111,98,106,101,99,116,62,10,60,47,114,101,115,111,117,114,
+99,101,62,10};
 
-static size_t xml_res_size_60 = 3414;
+static size_t xml_res_size_60 = 3729;
 static unsigned char xml_res_file_60[] = {
 60,63,120,109,108,32,118,101,114,115,105,111,110,61,34,49,46,48,34,32,101,
 110,99,111,100,105,110,103,61,34,73,83,79,45,56,56,53,57,45,49,34,63,62,
@@ -25672,114 +25687,128 @@ static unsigned char xml_res_file_60[] = {
 32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,105,122,101,62,49,53,44,
 45,49,100,60,47,115,105,122,101,62,10,32,32,32,32,32,32,32,32,32,32,32,
 32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,115,116,121,108,101,47,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,
-120,83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,101,61,34,116,
-120,116,78,111,116,101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,60,108,97,98,101,108,62,78,111,116,101,58,32,84,104,101,32,98,
-97,99,107,117,112,32,102,111,114,109,97,116,32,119,105,108,108,32,98,101,
-32,80,76,65,73,78,46,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,60,112,111,115,62,56,44,50,53,100,60,47,112,
-111,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,116,
-121,108,101,47,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,
-98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,
-98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,67,104,101,99,107,
-66,111,120,34,32,110,97,109,101,61,34,99,104,107,86,101,114,98,111,115,
-101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,
-98,101,108,62,86,101,114,98,111,115,101,32,109,101,115,115,97,103,101,115,
-60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,99,104,101,99,107,101,100,62,49,60,47,99,104,101,99,107,101,100,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,112,111,115,62,
-49,48,44,49,52,52,100,60,47,112,111,115,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,60,115,101,108,101,99,116,101,100,62,49,60,47,115,101,108,101,
-99,116,101,100,62,10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,
-99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,112,111,115,62,50,44,50,100,
-60,47,112,111,115,62,10,32,32,32,32,32,32,32,32,32,32,60,115,105,122,101,
-62,50,52,53,44,49,55,52,100,60,47,115,105,122,101,62,10,32,32,32,32,32,
-32,32,32,32,32,60,115,116,121,108,101,62,119,120,78,66,95,66,79,84,84,79,
-77,60,47,115,116,121,108,101,62,10,32,32,32,32,32,32,32,32,32,32,60,111,
-98,106,101,99,116,32,99,108,97,115,115,61,34,110,111,116,101,98,111,111,
-107,112,97,103,101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,108,
-97,98,101,108,62,77,101,115,115,97,103,101,115,60,47,108,97,98,101,108,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,
-108,97,115,115,61,34,119,120,84,101,120,116,67,116,114,108,34,32,110,97,
-109,101,61,34,116,120,116,77,101,115,115,97,103,101,115,34,62,10,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,60,115,116,121,108,101,62,119,120,84,
-69,95,77,85,76,84,73,76,73,78,69,124,119,120,84,69,95,82,69,65,68,79,78,
-76,89,124,119,120,72,83,67,82,79,76,76,60,47,115,116,121,108,101,62,10,
-32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
-32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,
-32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,
-102,108,97,103,62,119,120,84,79,80,124,119,120,66,79,84,84,79,77,124,119,
-120,76,69,70,84,124,119,120,82,73,71,72,84,124,119,120,69,88,80,65,78,68,
-124,119,120,71,82,79,87,124,119,120,65,76,73,71,78,95,67,69,78,84,82,69,
-60,47,102,108,97,103,62,10,32,32,32,32,32,32,60,47,111,98,106,101,99,116,
-62,10,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
-34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,
-60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,70,108,101,
-120,71,114,105,100,83,105,122,101,114,34,62,10,32,32,32,32,32,32,32,32,
-32,32,60,99,111,108,115,62,52,60,47,99,111,108,115,62,10,32,32,32,32,32,
-32,32,32,32,32,60,114,111,119,115,62,49,60,47,114,111,119,115,62,10,32,
-32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
-61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,
-32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,
-120,66,117,116,116,111,110,34,32,110,97,109,101,61,34,119,120,73,68,95,
-72,69,76,80,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,
-98,101,108,62,38,97,109,112,59,72,101,108,112,60,47,108,97,98,101,108,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,112,111,115,62,50,44,49,
-51,53,100,60,47,112,111,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,
-47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,102,
-108,97,103,62,119,120,84,79,80,124,119,120,66,79,84,84,79,77,124,119,120,
-76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,
-32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,53,60,47,98,
-111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
-101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,
-32,99,108,97,115,115,61,34,115,112,97,99,101,114,34,62,10,32,32,32,32,32,
-32,32,32,32,32,32,32,60,115,105,122,101,62,48,44,48,60,47,115,105,122,101,
-62,10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
-32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
-61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,
-32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,
-120,66,117,116,116,111,110,34,32,110,97,109,101,61,34,119,120,73,68,95,
-79,75,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,
-108,62,38,97,109,112,59,79,75,60,47,108,97,98,101,108,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,60,100,101,102,97,117,108,116,62,49,60,47,
-100,101,102,97,117,108,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,60,112,111,115,62,57,51,44,49,51,53,100,60,47,112,111,115,62,10,32,32,
+32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
+83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,101,61,34,115,116,
+82,111,108,101,110,97,109,101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,108,97,98,101,108,62,82,111,108,101,110,97,109,101,60,
+47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,60,112,111,115,62,56,44,50,55,100,60,47,112,111,115,62,10,32,32,32,32,
 32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,
-32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,84,79,80,124,119,
-120,66,79,84,84,79,77,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,
-60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,
-114,100,101,114,62,53,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,
-32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,
-32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,
-114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,111,
-98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,66,117,116,116,111,
-110,34,32,110,97,109,101,61,34,119,120,73,68,95,67,65,78,67,69,76,34,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,38,
-97,109,112,59,67,97,110,99,101,108,60,47,108,97,98,101,108,62,10,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,60,112,111,115,62,49,52,54,44,49,51,
-53,100,60,47,112,111,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,47,
-111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,102,
-108,97,103,62,119,120,84,79,80,124,119,120,66,79,84,84,79,77,124,119,120,
-76,69,70,84,124,119,120,82,73,71,72,84,124,119,120,69,88,80,65,78,68,124,
-119,120,71,82,79,87,124,119,120,65,76,73,71,78,95,82,73,71,72,84,60,47,
+32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,
+115,115,61,34,119,120,84,101,120,116,67,116,114,108,34,32,110,97,109,101,
+61,34,116,120,116,82,111,108,101,110,97,109,101,34,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,112,111,115,62,54,53,44,50,53,100,60,
+47,112,111,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
+115,105,122,101,62,49,53,48,44,45,49,100,60,47,115,105,122,101,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,116,121,108,101,47,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
+99,108,97,115,115,61,34,119,120,83,116,97,116,105,99,84,101,120,116,34,
+32,110,97,109,101,61,34,116,120,116,78,111,116,101,34,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,78,111,116,
+101,58,32,84,104,101,32,98,97,99,107,117,112,32,102,111,114,109,97,116,
+32,119,105,108,108,32,98,101,32,80,76,65,73,78,46,60,47,108,97,98,101,108,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,112,111,115,62,
+56,44,52,55,100,60,47,112,111,115,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,115,116,121,108,101,47,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,
+119,120,67,104,101,99,107,66,111,120,34,32,110,97,109,101,61,34,99,104,
+107,86,101,114,98,111,115,101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,108,97,98,101,108,62,86,101,114,98,111,115,101,32,109,
+101,115,115,97,103,101,115,60,47,108,97,98,101,108,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,99,104,101,99,107,101,100,62,49,60,
+47,99,104,101,99,107,101,100,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,112,111,115,62,49,48,44,49,52,52,100,60,47,112,111,115,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,60,115,101,108,101,99,116,101,100,
+62,49,60,47,115,101,108,101,99,116,101,100,62,10,32,32,32,32,32,32,32,32,
+32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,
+112,111,115,62,50,44,50,100,60,47,112,111,115,62,10,32,32,32,32,32,32,32,
+32,32,32,60,115,105,122,101,62,50,52,53,44,49,55,52,100,60,47,115,105,122,
+101,62,10,32,32,32,32,32,32,32,32,32,32,60,115,116,121,108,101,62,119,120,
+78,66,95,66,79,84,84,79,77,60,47,115,116,121,108,101,62,10,32,32,32,32,
+32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,110,
+111,116,101,98,111,111,107,112,97,103,101,34,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,60,108,97,98,101,108,62,77,101,115,115,97,103,101,115,60,
+47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
+106,101,99,116,32,99,108,97,115,115,61,34,119,120,84,101,120,116,67,116,
+114,108,34,32,110,97,109,101,61,34,116,120,116,77,101,115,115,97,103,101,
+115,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,116,121,108,
+101,62,119,120,84,69,95,77,85,76,84,73,76,73,78,69,124,119,120,84,69,95,
+82,69,65,68,79,78,76,89,124,119,120,72,83,67,82,79,76,76,60,47,115,116,
+121,108,101,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
+101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,
+116,62,10,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
+32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,84,79,80,124,119,120,
+66,79,84,84,79,77,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,124,
+119,120,69,88,80,65,78,68,124,119,120,71,82,79,87,124,119,120,65,76,73,
+71,78,95,67,69,78,84,82,69,60,47,102,108,97,103,62,10,32,32,32,32,32,32,
+60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,60,111,98,106,101,99,
+116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,
+10,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
+61,34,119,120,70,108,101,120,71,114,105,100,83,105,122,101,114,34,62,10,
+32,32,32,32,32,32,32,32,32,32,60,99,111,108,115,62,52,60,47,99,111,108,
+115,62,10,32,32,32,32,32,32,32,32,32,32,60,114,111,119,115,62,49,60,47,
+114,111,119,115,62,10,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
+116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
+97,115,115,61,34,119,120,66,117,116,116,111,110,34,32,110,97,109,101,61,
+34,119,120,73,68,95,72,69,76,80,34,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,108,97,98,101,108,62,38,97,109,112,59,72,101,108,112,60,
+47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
+112,111,115,62,50,44,49,51,53,100,60,47,112,111,115,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,60,102,108,97,103,62,119,120,84,79,80,124,119,120,66,
+79,84,84,79,77,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,
 102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,
 100,101,114,62,53,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,
 32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,
-32,60,103,114,111,119,97,98,108,101,99,111,108,115,62,49,60,47,103,114,
-111,119,97,98,108,101,99,111,108,115,62,10,32,32,32,32,32,32,32,32,60,47,
-111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,102,108,97,103,62,
-119,120,69,88,80,65,78,68,124,119,120,71,82,79,87,60,47,102,108,97,103,
-62,10,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,
-32,60,103,114,111,119,97,98,108,101,99,111,108,115,62,48,60,47,103,114,
-111,119,97,98,108,101,99,111,108,115,62,10,32,32,32,32,32,32,60,103,114,
-111,119,97,98,108,101,114,111,119,115,62,48,60,47,103,114,111,119,97,98,
-108,101,114,111,119,115,62,10,32,32,32,32,60,47,111,98,106,101,99,116,62,
-10,32,32,60,47,111,98,106,101,99,116,62,10,60,47,114,101,115,111,117,114,
-99,101,62,10};
+32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,112,97,99,101,
+114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,115,105,122,101,62,
+48,44,48,60,47,115,105,122,101,62,10,32,32,32,32,32,32,32,32,32,32,60,47,
+111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
+101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,
+34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
+99,108,97,115,115,61,34,119,120,66,117,116,116,111,110,34,32,110,97,109,
+101,61,34,119,120,73,68,95,79,75,34,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,108,97,98,101,108,62,38,97,109,112,59,79,75,60,47,108,97,
+98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,100,101,102,
+97,117,108,116,62,49,60,47,100,101,102,97,117,108,116,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,112,111,115,62,57,51,44,49,51,53,100,60,
+47,112,111,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
+101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,
+62,119,120,84,79,80,124,119,120,66,79,84,84,79,77,124,119,120,76,69,70,
+84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,53,60,47,98,111,114,100,
+101,114,62,10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,
+62,10,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
+97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
+61,34,119,120,66,117,116,116,111,110,34,32,110,97,109,101,61,34,119,120,
+73,68,95,67,65,78,67,69,76,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,108,97,98,101,108,62,38,97,109,112,59,67,97,110,99,101,108,60,
+47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
+112,111,115,62,49,52,54,44,49,51,53,100,60,47,112,111,115,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,84,79,80,124,119,120,
+66,79,84,84,79,77,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,124,
+119,120,69,88,80,65,78,68,124,119,120,71,82,79,87,124,119,120,65,76,73,
+71,78,95,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,60,98,111,114,100,101,114,62,53,60,47,98,111,114,100,101,
+114,62,10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
+10,32,32,32,32,32,32,32,32,32,32,60,103,114,111,119,97,98,108,101,99,111,
+108,115,62,49,60,47,103,114,111,119,97,98,108,101,99,111,108,115,62,10,
+32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,
+32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,71,
+82,79,87,60,47,102,108,97,103,62,10,32,32,32,32,32,32,60,47,111,98,106,
+101,99,116,62,10,32,32,32,32,32,32,60,103,114,111,119,97,98,108,101,99,
+111,108,115,62,48,60,47,103,114,111,119,97,98,108,101,99,111,108,115,62,
+10,32,32,32,32,32,32,60,103,114,111,119,97,98,108,101,114,111,119,115,62,
+48,60,47,103,114,111,119,97,98,108,101,114,111,119,115,62,10,32,32,32,32,
+60,47,111,98,106,101,99,116,62,10,32,32,60,47,111,98,106,101,99,116,62,
+10,60,47,114,101,115,111,117,114,99,101,62,10};
 
 static size_t xml_res_size_61 = 3589;
 static unsigned char xml_res_file_61[] = {
-- 
1.7.1

